# Changelog

## [0.6.0](https://github.com/gotalab/skillport/compare/v0.5.2...v0.6.0) (2025-12-20)


### Features

* add GitHub shorthand format for add command ([#50](https://github.com/gotalab/skillport/issues/50)) ([4b0700d](https://github.com/gotalab/skillport/commit/4b0700d1ad0f22b8dbb361615cd99bdd7e9915a2))
* auto-detect GitHub auth via gh CLI ([#48](https://github.com/gotalab/skillport/issues/48)) ([758ac1f](https://github.com/gotalab/skillport/commit/758ac1f6ae442dd270805fef94ac9a7164cad119))

## [0.5.2](https://github.com/gotalab/skillport/compare/v0.5.1...v0.5.2) (2025-12-18)


### Bug Fixes

* align frontmatter validation with Agent Skills open standard ([#46](https://github.com/gotalab/skillport/issues/46)) ([0274cae](https://github.com/gotalab/skillport/commit/0274cae9aa1e760b66a1fa353a83816506781e22))

## [0.5.1](https://github.com/gotalab/skillport/compare/v0.5.0...v0.5.1) (2025-12-17)


### Bug Fixes

* upgrade lancedb to 0.26.0 and fix deprecation warnings ([#44](https://github.com/gotalab/skillport/issues/44)) ([52911ae](https://github.com/gotalab/skillport/commit/52911ae18531482fc763fca45e53ed7bfcf6e40e))

## [0.5.0](https://github.com/gotalab/skillport/compare/v0.4.1...v0.5.0) (2025-12-16)


### Features

* add location element and proper XML format for skill-client-integration spec compliance ([#42](https://github.com/gotalab/skillport/issues/42)) ([c052a45](https://github.com/gotalab/skillport/commit/c052a45f5419f2a4aec2c2c510c81606f3fdb317))

## [0.4.1](https://github.com/gotalab/skillport/compare/v0.4.0...v0.4.1) (2025-12-13)


### Bug Fixes

* **cli:** add Claude Code incompatibility warning for namespace option ([#40](https://github.com/gotalab/skillport/issues/40)) ([4951bdb](https://github.com/gotalab/skillport/commit/4951bdb72e466b010ecc5414e04ce71d144cd36a))

## [0.4.0](https://github.com/gotalab/skillport/compare/v0.3.1...v0.4.0) (2025-12-10)


### Features

* add zip file support for skill installation ([#37](https://github.com/gotalab/skillport/issues/37)) ([0b9fce4](https://github.com/gotalab/skillport/commit/0b9fce41cf315605c2aabc4ac8908948b7bafae2))

## [0.3.1](https://github.com/gotalab/skillport/compare/v0.3.0...v0.3.1) (2025-12-07)


### Bug Fixes

* use POSIX paths for cross-platform compatibility ([#35](https://github.com/gotalab/skillport/issues/35)) ([db7ad78](https://github.com/gotalab/skillport/commit/db7ad78cb878cbc51ca303a567f406a8b578b4fa))

## [0.3.0](https://github.com/gotalab/skillport/compare/v0.2.0...v0.3.0) (2025-12-07)


### Features

* show untracked skills in update command ([#31](https://github.com/gotalab/skillport/issues/31)) ([1e3a9dc](https://github.com/gotalab/skillport/commit/1e3a9dca8267eb14de804e951cad7fec2fa60098))
* show untracked skills in update command ([#34](https://github.com/gotalab/skillport/issues/34)) ([12873a1](https://github.com/gotalab/skillport/commit/12873a1c63805498ffa186c8d32cb74e7ca350a8))


### Reverts

* show untracked skills in update command ([6422fda](https://github.com/gotalab/skillport/commit/6422fdaa2326b003d0a7daa7264cc7a254d34f9b))

## [0.2.0](https://github.com/gotalab/skillport/compare/v0.1.6...v0.2.0) (2025-12-06)


### Features

* add Codex skills directory option to init command ([#29](https://github.com/gotalab/skillport/issues/29)) ([9d44f6e](https://github.com/gotalab/skillport/commit/9d44f6e0d5305936ba7d32a6b21d96e16f5772c0))
* add skill update command and configure ruff linting ([#26](https://github.com/gotalab/skillport/issues/26)) ([c6f0ab9](https://github.com/gotalab/skillport/commit/c6f0ab922c46216d51b1d9b730bf044f9863bd8a))


### Documentation

* add update command documentation and fix init example ([#30](https://github.com/gotalab/skillport/issues/30)) ([0c14b86](https://github.com/gotalab/skillport/commit/0c14b8695c4388c8f21ef7ff1d944d47ba5cbc4d))

## [0.1.6](https://github.com/gotalab/skillport/compare/v0.1.5...v0.1.6) (2025-12-05)


### Bug Fixes

* change cli command sync to doc ([a28d95c](https://github.com/gotalab/skillport/commit/a28d95c4440392c824e4e6daa145cbf4f2efa380))


### Documentation

* add Hugging Face Skills, remove SkillsMP Marketplace ([4f153cd](https://github.com/gotalab/skillport/commit/4f153cd0ac9c9582c6a81c30d0ab92b49fe0ca6c))
* add recommended community skills table to README ([913dc27](https://github.com/gotalab/skillport/commit/913dc27f498b8b1dc0d5dace2fb8311d977d2a2f))
* add recommended community skills table to README ([d40f04e](https://github.com/gotalab/skillport/commit/d40f04e5b6ef9f189fe93fceaf45e2b990f57748))
* update how to add codex skills ([4814997](https://github.com/gotalab/skillport/commit/4814997dbb2a2eedc711cc9412e4d5d24164fea2))

## [0.1.5](https://github.com/gotalab/skillport/compare/v0.1.4...v0.1.5) (2025-12-04)


### Bug Fixes

* change dir name ([5d75837](https://github.com/gotalab/skillport/commit/5d758376a1d5c5a721b63e02a807c5804927152e))
* enforce strict frontmatter validation on add ([56e36e1](https://github.com/gotalab/skillport/commit/56e36e1df02f23705cbf7e23d067b2b2de961c60))
* enforce strict frontmatter validation on add ([b56fee9](https://github.com/gotalab/skillport/commit/b56fee94daf4ef105ba1d2fa469102c9ada21ce3))


### Documentation

* translate guide to English and update CONTRIBUTING.md ([2387d25](https://github.com/gotalab/skillport/commit/2387d2506b52655d80b0270b29f76f11770563d2))
* translate guide to English and update CONTRIBUTING.md ([749c272](https://github.com/gotalab/skillport/commit/749c27260d14bceaaf086647294c8e38ecdef05a))

## [0.1.4](https://github.com/gotalab/skillport/compare/v0.1.3...v0.1.4) (2025-12-03)


### Features

* add skill-evaluator skill ([591ccbe](https://github.com/gotalab/skillport/commit/591ccbe803376e6f73f4be2a02bb104afceed1a3))
* **validation:** add frontmatter validation rules ([d97fda4](https://github.com/gotalab/skillport/commit/d97fda4802275519eef742e6515897543d693b65))
* **validation:** add frontmatter validation rules ([1ba8884](https://github.com/gotalab/skillport/commit/1ba8884ccc81bad6f622a6429a89e0870431ad2d))


### Documentation

* add README in .agent/skills/ ([0ae05b5](https://github.com/gotalab/skillport/commit/0ae05b5d9d501ed077911f468de2217833b773f5))
* add README in .agent/skills/ ([f2d5523](https://github.com/gotalab/skillport/commit/f2d55238c11021cb480a56a7c86964eeea0681e2))
* clarify CLI init/add flow ([495defa](https://github.com/gotalab/skillport/commit/495defa8a547c2173a585e8f17c9e2f4d21d5c4a))
* clarify CLI init/add flow ([0a4b887](https://github.com/gotalab/skillport/commit/0a4b88752bde7ce140bce4bd5874e8b1aff27918))
* clarify CLI init/add flow ([a0ff6b2](https://github.com/gotalab/skillport/commit/a0ff6b2b725b458e65f0ca50b80507423837e58c))


### Miscellaneous Chores

* prepare release ([2684deb](https://github.com/gotalab/skillport/commit/2684debe9b5bc4764afdd348e0d7e088a89e7c8f))

## [0.1.3](https://github.com/gotalab/skillport/compare/v0.1.2...v0.1.3) (2025-12-02)


### Bug Fixes

* use raw FTS scores and fix scalar index  ([24442a9](https://github.com/gotalab/skillport/commit/24442a96873148150c797ffc46f364e2e2073b8d))
* use raw FTS scores and fix scalar index type ([9e04d26](https://github.com/gotalab/skillport/commit/9e04d26366e3aab4e0c11f54a7caf145ccab77ff))

## [0.1.2](https://github.com/gotalab/skillport/compare/v0.1.1...v0.1.2) (2025-12-02)


### Bug Fixes

* auto reindex read commands ([230a729](https://github.com/gotalab/skillport/commit/230a729c56bb383bde4fa4c3f38b50a25bdcd323))

## [0.1.1](https://github.com/gotalab/skillport/compare/v0.1.0...v0.1.1) (2025-12-02)


### Features

* **cli:** add global skills/db overrides ([c6bd235](https://github.com/gotalab/skillport/commit/c6bd2352609202fa627b89f845a9ca0ca96fa087))
* **cli:** add global skills/db overrides ([a8d3c44](https://github.com/gotalab/skillport/commit/a8d3c44ccb5aa692156ec29b71060b97ae353883))
* derive db/meta per skills dir and improve add UX ([111889a](https://github.com/gotalab/skillport/commit/111889a386439225d8b9831ca06ed0e96283881b))
* initial release ([82cdaea](https://github.com/gotalab/skillport/commit/82cdaea69cfc22aa93307f94b0ef3be83131782b))


### Bug Fixes

* clean prefetched github temp dir after rename ([780cd5d](https://github.com/gotalab/skillport/commit/780cd5d5409bf1e09f0adfdb21152e7f516ff597))
* reuse fetched source and embedding defaults ([d250ea3](https://github.com/gotalab/skillport/commit/d250ea377676e8df4ae789b93b3db58d8963d658))


### Documentation

* align config sample to AGENTS+GEMINI ([eb900b6](https://github.com/gotalab/skillport/commit/eb900b663c7d69d6210cde0664597d092d236bad))
* mention Antigravity in other clients list ([99778c7](https://github.com/gotalab/skillport/commit/99778c78c68900575e7c93d67730d1e4feede01c))


### Miscellaneous Chores

* set release package name ([6e63e66](https://github.com/gotalab/skillport/commit/6e63e666427930dc62baac842ea61070a29ded6a))
